# cpplint hook

`cpplinthook` is a module for linting C++ code using `cpplint`.

## Hacking

To work on this repository:

1. Clone it
1. Create a virtual env with `python3 -m venv ve`
1. Activate the virtual env with `source ve/bin/activate`
1. Install the developer dependencies with `pip install -e .[develop]`
1. Hack hack hack
1. Run the tests before submitting with `nose2`

### Tests

Run `mypy cpplinthook` to ensure your types are well-defined.

Enjoy!
